@@ -55,12 +55,12 @@ OC.L10N.register(
     "Install the browser extension" : "Усталюйце пашырэнне для браўзера",
     "Step 2" : "Крок 2",
     "Enable for the current domain" : "Уключыце для бягучага дамена",
-    "About" : "Аб праграме",
     "Archive" : "Архіў",
     "Delete" : "Выдаліць",
     "Search" : "Пошук",
     "Send" : "Адправіць",
     "Refresh" : "Абнавіць",
+    "About" : "Аб праграме",
     "Ok" : "ОК",
     "Send later" : "Адправіць пазней",
     "From" : "Ад",
@@ -144,6 +144,7 @@ OC.L10N.register(
     "Remove {email}" : "Выдаліць {email}",
     "Add folder" : "Дадаць папку",
     "Folder name" : "Назва папкі",
+    "Saving" : "Захаванне",
     "Move up" : "Перамясціць уверх",
     "Move down" : "Перамясціць уніз",
     "Show all folders" : "Паказаць усе папкі",
@@ -191,6 +192,7 @@ OC.L10N.register(
     "Could not create task" : "Не ўдалося стварыць заданне",
     "No calendars with task list support" : "Няма календароў з падтрымкай спісаў заднняў",
     "Not found" : "Не знойдзена",
+    "Go to latest message" : "Перайсці да апошняга паведамлення",
     "Newest message" : "Апошняе паведамленне",
     "Please select languages to translate to and from" : "Выберыце, з якой мовы на якую перакладаць",
     "The message could not be translated" : "Не ўдалося перакласці паведамленне ",
@@ -214,11 +216,18 @@ OC.L10N.register(
     "Seen" : "Прачытанае",
     "Delete filter" : "Выдаліць фільтр",
     "New filter" : "Новы фільтр",
+    "Filter saved" : "Фільтр захаваны",
+    "Could not save filter" : "Не ўдалося захаваць фільтр",
+    "Filter deleted" : "Фільтр выдалены",
+    "Could not delete filter" : "Не ўдалося выдаліць фільтр",
     "Filter is active" : "Фільтр актыўны",
     "Filter is not active" : "Фільтр неактыўны",
     "Help" : "Даведка",
     "Enter subject" : "Увядзіце тэму",
+    "Conditions" : "Умовы",
+    "Add condition" : "Дадаць умову",
     "Actions" : "Дзеянні",
+    "Add action" : "Дадаць дзеянне",
     "Priority" : "Прыярытэт",
     "Enable filter" : "Уключыць фільтр",
     "Tag" : "Тэг",
