@@ -105,6 +105,7 @@ OC.L10N.register(
     "Sorting" : "Rendezés",
     "Newest first" : "Legújabb elöl",
     "Oldest first" : "Régebbiek elöl",
+    "Text blocks" : "Szövegblokkok",
     "Shared with me" : "Megosztva velem",
     "Privacy" : "Adatvédelem",
     "Security" : "Biztonság",
@@ -278,7 +279,6 @@ OC.L10N.register(
     "Last month" : "Előző hónap",
     "Choose target folder" : "Válasszon célmappát",
     "No more submailboxes in here" : "Nem találhatók további alpostafiókok",
-    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Az üzeneteket automatikusan fontosként jelöli meg az alapján, hogy mely üzenetekre reagált, vagy jelölt meg fontosként. Kezdetben lehet, hogy kézzel megváltoztatnia a fontosságot és ezzel kell tanítania a rendszert, de ez az idő múlásával javulni fog.",
     "Favorites" : "Kedvencek",
     "Follow up" : "Emlékeztető",
     "Follow up info" : "Emlékeztető információ",
@@ -589,6 +589,7 @@ OC.L10N.register(
     "Private key (optional)" : "Titkos kulcs (nem kötelező)",
     "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "A titkos kulcs csak akkor szükséges, ha aláírt és titkosított e-maileket akar küldeni a tanúsítvány használatával.",
     "Submit" : "Beküldés",
+    "No text blocks available" : "Nincsenek elérhető szövegblokkok",
     "Group" : "Csoport",
     "Shared" : "Megosztva",
     "Shares" : "Megosztások",
@@ -630,6 +631,7 @@ OC.L10N.register(
     "The link leads to %s" : "A hivatkozás ide mutat: %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Ha nem akarja megnyitni azt az oldalt, akkor térjen vissza a <a href=\"%s\">Levelezéshez</a>.",
     "Continue to %s" : "Folytatás ide: %s",
+    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Az üzeneteket automatikusan fontosként jelöli meg az alapján, hogy mely üzenetekre reagált, vagy jelölt meg fontosként. Kezdetben lehet, hogy kézzel megváltoztatnia a fontosságot és ezzel kell tanítania a rendszert, de ez az idő múlásával javulni fog.",
     "Mark all messages of this folder as read" : "A mappában található összes üzenet megjelölése olvasottként",
     "Last 7 days" : "Előző 7 nap"
 },
