@@ -17,11 +17,11 @@ OC.L10N.register(
     "Newest first" : "Imaynuten d imezwura",
     "Oldest first" : "Iqbuṛen d imezwura",
     "Privacy" : "Vie privée",
-    "About" : "Γef",
     "Delete" : "Kkes",
     "Search" : "Nadi",
     "Send" : "Tuzna",
     "Refresh" : "Sismeḍ",
+    "About" : "Γef",
     "Ok" : "Ih",
     "Choose" : "Fren",
     "Confirm" : "Serggeg",
@@ -58,6 +58,7 @@ OC.L10N.register(
     "Close" : "Mdel",
     "Date" : "Azemz",
     "Tags" : "Tibzimin",
+    "Task created" : "Tawuri tettwarna",
     "Not found" : "Ulac-it",
     "Translate from" : "Suqel seg",
     "Translate to" : "Suqel ar",
@@ -68,6 +69,7 @@ OC.L10N.register(
     "User" : "Aseqdac",
     "Guest" : "Inebgi",
     "Group" : "Agraw",
+    "Shared" : "Yettwabḍa",
     "Account connected" : "Amiḍan d uqqin",
     "All" : "Akk",
     "Inbox" : "Tanaka",
