@@ -87,6 +87,7 @@ OC.L10N.register(
     "Date" : "Data",
     "Tags" : "Etiquetas",
     "Custom" : "Personalizats",
+    "Not found" : "Non trobat",
     "Translate message" : "Traduire lo messatge",
     "Translating" : "Traduccion",
     "Untitled event" : "Eveniment sens títol",
@@ -108,6 +109,7 @@ OC.L10N.register(
     "Group" : "Grop",
     "Shared" : "Partejat",
     "Shares" : "Partatges",
+    "Insert" : "Inserir",
     "Account connected" : "Compte connectat",
     "All" : "Tot",
     "Drafts" : "Borrolhons",
