@@ -40,6 +40,7 @@ OC.L10N.register(
     "Refresh" : "Refresh",
     "About" : "Kuhusu",
     "Ok" : "Sawa",
+    "Send later" : "Tuma baadaye",
     "From" : "Tangu/ kutoka",
     "Select account" : "Chagua akaunti",
     "To" : "Mpaka/ hadi",
@@ -47,6 +48,7 @@ OC.L10N.register(
     "Subject" : "Subject",
     "Draft saved" : "Draft saved",
     "Smart picker" : "Smart picker",
+    "Send now" : "Tuma sasa",
     "Choose" : "Chagua",
     "Choose a file to add as attachment" : "Chagua faili kuongeza kama kiambatanisho",
     "Choose a file to share as a link" : "Chagua faili kushirikisha kama kiungo",
@@ -75,8 +77,10 @@ OC.L10N.register(
     "Create event" : "Tengeneza matukio",
     "All day" : "Siku yote",
     "Attendees" : "Wahudhuriaji",
+    "Select calendar" : "Select calendar",
     "Description" : "Maelezo",
     "Create" : "Tengeneza",
+    "This event was cancelled" : "This event was cancelled",
     "Select" : "Chagua",
     "Comment" : "Maoni",
     "Accept" : "Kubali",
