@@ -31,6 +31,7 @@ use OCP\AppFramework\Controller;
 use OCP\AppFramework\Http;
 use OCP\AppFramework\Http\Attribute\OpenAPI;
 use OCP\AppFramework\Http\JSONResponse;
+use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\IConfig;
 use OCP\IL10N;
 use OCP\IRequest;
@@ -52,7 +53,8 @@ class AccountsController extends Controller {
 	private IRemoteHostValidator $hostValidator;
 	private MailboxSync $mailboxSync;
 
-	public function __construct(string $appName,
+	public function __construct(
+		string $appName,
 		IRequest $request,
 		AccountService $accountService,
 		$UserId,
@@ -66,6 +68,7 @@ class AccountsController extends Controller {
 		IConfig $config,
 		IRemoteHostValidator $hostValidator,
 		MailboxSync $mailboxSync,
+		private ITimeFactory $timeFactory,
 	) {
 		parent::__construct($appName, $request);
 		$this->accountService = $accountService;
@@ -211,6 +214,7 @@ class AccountsController extends Controller {
 	 * @param int|null $archiveMailboxId
 	 * @param int|null $snoozeMailboxId
 	 * @param bool|null $signatureAboveQuote
+	 * @param bool|null $classificationEnabled
 	 *
 	 * @return JSONResponse
 	 *
@@ -229,7 +233,10 @@ class AccountsController extends Controller {
 		?bool $signatureAboveQuote = null,
 		?int $trashRetentionDays = null,
 		?int $junkMailboxId = null,
-		?bool $searchBody = null): JSONResponse {
+		?bool $searchBody = null,
+		?bool $classificationEnabled = null,
+		?bool $imipCreate = null,
+	): JSONResponse {
 		$account = $this->accountService->find($this->currentUserId, $id);
 
 		$dbAccount = $account->getMailAccount();
@@ -277,6 +284,12 @@ class AccountsController extends Controller {
 		if ($searchBody !== null) {
 			$dbAccount->setSearchBody($searchBody);
 		}
+		if ($classificationEnabled !== null) {
+			$dbAccount->setClassificationEnabled($classificationEnabled);
+		}
+		if ($imipCreate !== null) {
+			$dbAccount->setImipCreate($imipCreate);
+		}
 		return new JSONResponse(
 			new Account($this->accountService->save($dbAccount))
 		);
@@ -330,6 +343,7 @@ class AccountsController extends Controller {
 	 * @param string|null $smtpUser
 	 * @param string|null $smtpPassword
 	 * @param string $authMethod
+	 * @param bool|null $classificationEnabled
 	 *
 	 * @return JSONResponse
 	 */
@@ -346,7 +360,8 @@ class AccountsController extends Controller {
 		?string $smtpSslMode = null,
 		?string $smtpUser = null,
 		?string $smtpPassword = null,
-		string $authMethod = 'password'): JSONResponse {
+		string $authMethod = 'password',
+		?bool $classificationEnabled = null): JSONResponse {
 		if ($this->config->getAppValue(Application::APP_ID, 'allow_new_mail_accounts', 'yes') === 'no') {
 			$this->logger->info('Creating account disabled by admin.');
 			return MailJsonResponse::error('Could not create account');
@@ -378,7 +393,14 @@ class AccountsController extends Controller {
 			);
 		}
 		try {
-			$account = $this->setup->createNewAccount($accountName, $emailAddress, $imapHost, $imapPort, $imapSslMode, $imapUser, $imapPassword, $smtpHost, $smtpPort, $smtpSslMode, $smtpUser, $smtpPassword, $this->currentUserId, $authMethod);
+			$account = $this->setup->createNewAccount($accountName, $emailAddress, $imapHost, $imapPort, $imapSslMode, $imapUser, $imapPassword, $smtpHost, $smtpPort, $smtpSslMode, $smtpUser, $smtpPassword, $this->currentUserId, $authMethod, null, $classificationEnabled);
+			// Set initial heartbeat
+			$this->config->setUserValue(
+				$account->getUserId(),
+				Application::APP_ID,
+				'ui-heartbeat',
+				(string)$this->timeFactory->getTime(),
+			);
 		} catch (CouldNotConnectException $e) {
 			$data = [
 				'error' => $e->getReason(),
