@@ -30,20 +30,20 @@ class SettingsController extends Controller {
 	private AntiSpamService $antiSpamService;
 	private ContainerInterface $container;
 	private IConfig $config;
-	private ClassificationSettingsService $classificationSettingsService;
 
-	public function __construct(IRequest $request,
+	public function __construct(
+		IRequest $request,
 		ProvisioningManager $provisioningManager,
 		AntiSpamService $antiSpamService,
 		IConfig $config,
 		ContainerInterface $container,
-		ClassificationSettingsService $classificationSettingsService) {
+		private ClassificationSettingsService $classificationSettingsService,
+	) {
 		parent::__construct(Application::APP_ID, $request);
 		$this->provisioningManager = $provisioningManager;
 		$this->antiSpamService = $antiSpamService;
 		$this->config = $config;
 		$this->container = $container;
-		$this->classificationSettingsService = $classificationSettingsService;
 	}
 
 	public function index(): JSONResponse {
@@ -118,15 +118,13 @@ class SettingsController extends Controller {
 		$this->config->setAppValue('mail', 'llm_processing', $enabled ? 'yes' : 'no');
 		return new JSONResponse([]);
 	}
-
+	public function setLayoutMessageView(string $value): JSONResponse {
+		$this->config->setAppValue('mail', 'layout_message_view', $value);
+		return new JSONResponse([]);
+	}
 	public function setImportanceClassificationEnabledByDefault(bool $enabledByDefault): JSONResponse {
 		$this->classificationSettingsService->setClassificationEnabledByDefault($enabledByDefault);
 		return new JSONResponse([]);
 	}
 
-	public function setLayoutMessageView(string $value): JSONResponse {
-		$this->config->setAppValue('mail', 'layout_message_view', $value);
-		return new JSONResponse([]);
-	}
-
 }
