@@ -84,6 +84,7 @@ class Message extends Entity implements JsonSerializable {
 		'forwarded',
 		'$junk',
 		'$notjunk',
+		'$phishing',
 		'$mdnsent',
 		Tag::LABEL_IMPORTANT,
 		'$important' // @todo remove this when we have removed all references on IMAP to $important @link https://github.com/nextcloud/mail/issues/25
@@ -142,6 +143,8 @@ class Message extends Entity implements JsonSerializable {
 
 	/** @var bool */
 	private $fetchAvatarFromClient = false;
+	/** @var array */
+	private $attachments = [];
 
 	public function __construct() {
 		$this->from = new AddressList([]);
@@ -314,6 +317,14 @@ class Message extends Entity implements JsonSerializable {
 		return $this->avatar;
 	}
 
+	public function setAttachments(array $attachments): void {
+		$this->attachments = $attachments;
+	}
+
+	public function getAttachments(): array {
+		return $this->attachments;
+	}
+
 	#[\Override]
 	#[ReturnTypeWillChange]
 	public function jsonSerialize() {
@@ -359,6 +370,7 @@ class Message extends Entity implements JsonSerializable {
 			'mentionsMe' => $this->getMentionsMe(),
 			'avatar' => $this->avatar?->jsonSerialize(),
 			'fetchAvatarFromClient' => $this->fetchAvatarFromClient,
+			'attachments' => $this->getAttachments(),
 		];
 	}
 }
