@@ -881,7 +881,6 @@ class MessageMapper {
 		$structureQuery = new Horde_Imap_Client_Fetch_Query();
 		$structureQuery->structure();
 		$structureQuery->headerText([
-			'cache' => true,
 			'peek' => true,
 		]);
 		$this->smimeService->addEncryptionCheckQueries($structureQuery);
@@ -946,17 +945,28 @@ class MessageMapper {
 				return new MessageStructureData($hasAttachments, $text, $isImipMessage, $isEncrypted, false);
 			}
 
-			// Convert a given binary body to utf-8 according to the transfer encoding and content
-			// type headers of the underlying MIME part
-			$convertBody = function (string $body, Horde_Mime_Headers $mimeHeaders) use ($structure): string {
+			/** Convert a given binary body to utf-8 according to the applicable
+			 * transfer encoding and content type headers. */
+			$convertBody = function (string $bodyId, string $bodyContent) use ($structure, $part, $fetchData): string {
+				/** @var Horde_Mime_Headers $mimeHeaders */
+				$mimeHeaders = $part->getMimeHeader($bodyId, Horde_Imap_Client_Data_Fetch::HEADER_PARSE);
+
+				/** @var Horde_Mime_Headers $messageHeaders */
+				$messageHeaders = $fetchData->getHeaderText('0', Horde_Imap_Client_Data_Fetch::HEADER_PARSE);
+
 				/** @var Horde_Mime_Headers_ContentParam_ContentType $contentType */
-				$contentType = $mimeHeaders->getHeader('content-type');
+				$contentType
+					= $mimeHeaders->getHeader('content-type')
+					?? $messageHeaders->getHeader('content-type');
+
 				/** @var Horde_Mime_Headers_ContentTransferEncoding $transferEncoding */
-				$transferEncoding = $mimeHeaders->getHeader('content-transfer-encoding');
+				$transferEncoding
+					= $mimeHeaders->getHeader('content-transfer-encoding')
+					?? $messageHeaders->getHeader('content-transfer-encoding');
 
 				if (!$contentType && !$transferEncoding) {
 					// Nothing to convert here ...
-					return $body;
+					return $bodyContent;
 				}
 
 				if ($transferEncoding) {
@@ -970,15 +980,14 @@ class MessageMapper {
 					}
 				}
 
-				$structure->setContents($body);
+				$structure->setContents($bodyContent);
 				return $this->converter->convert($structure);
 			};
 
 
 			$htmlBody = ($htmlBodyId !== null) ? $part->getBodyPart($htmlBodyId) : null;
 			if (!empty($htmlBody)) {
-				$mimeHeaders = $part->getMimeHeader($htmlBodyId, Horde_Imap_Client_Data_Fetch::HEADER_PARSE);
-				$htmlBody = $convertBody($htmlBody, $mimeHeaders);
+				$htmlBody = $convertBody($htmlBodyId, $htmlBody);
 				$mentionsUser = $this->checkLinks($htmlBody, $emailAddress);
 				$html = new Html2Text($htmlBody, ['do_links' => 'none','alt_image' => 'hide']);
 				return new MessageStructureData(
@@ -989,11 +998,10 @@ class MessageMapper {
 					$mentionsUser,
 				);
 			}
-			$textBody = $part->getBodyPart($textBodyId);
 
+			$textBody = $part->getBodyPart($textBodyId);
 			if (!empty($textBody)) {
-				$mimeHeaders = $part->getMimeHeader($textBodyId, Horde_Imap_Client_Data_Fetch::HEADER_PARSE);
-				$textBody = $convertBody($textBody, $mimeHeaders);
+				$textBody = $convertBody($textBodyId, $textBody);
 				return new MessageStructureData(
 					$hasAttachments,
 					$textBody,
