@@ -133,7 +133,8 @@ class MicrosoftIntegration {
 	}
 
 	public function refresh(Account $account): Account {
-		if ($account->getMailAccount()->getOauthTokenTtl() === null || $account->getMailAccount()->getOauthRefreshToken() === null) {
+		$oauthRefreshToken = $account->getMailAccount()->getOauthRefreshToken();
+		if ($account->getMailAccount()->getOauthTokenTtl() === null || $oauthRefreshToken === null) {
 			// Account is not authorized yet
 			return $account;
 		}
@@ -152,7 +153,7 @@ class MicrosoftIntegration {
 			return $account;
 		}
 
-		$refreshToken = $this->crypto->decrypt($account->getMailAccount()->getOauthRefreshToken());
+		$refreshToken = $this->crypto->decrypt($oauthRefreshToken);
 		$clientSecret = $this->crypto->decrypt($encryptedClientSecret);
 		$httpClient = $this->clientService->newClient();
 		try {
