@@ -11,7 +11,7 @@ declare(strict_types=1);
 namespace OCA\Mail\Service;
 
 use OCA\Mail\Account;
-use OCA\Mail\AppInfo\Application;
+use OCA\Mail\BackgroundJob\ContextChat\ScheduleJob;
 use OCA\Mail\BackgroundJob\PreviewEnhancementProcessingJob;
 use OCA\Mail\BackgroundJob\QuotaJob;
 use OCA\Mail\BackgroundJob\RepairSyncJob;
@@ -176,14 +176,6 @@ class AccountService {
 		// Insert background jobs for this account
 		$this->scheduleBackgroundJobs($newAccount->getId());
 
-		// Set initial heartbeat
-		$this->config->setUserValue(
-			$newAccount->getUserId(),
-			Application::APP_ID,
-			'ui-heartbeat',
-			(string)$this->timeFactory->getTime(),
-		);
-
 		return $newAccount;
 	}
 
@@ -239,6 +231,7 @@ class AccountService {
 		$this->scheduleBackgroundJob(TrainImportanceClassifierJob::class, $now, $arguments);
 		$this->scheduleBackgroundJob(PreviewEnhancementProcessingJob::class, $now, $arguments);
 		$this->scheduleBackgroundJob(QuotaJob::class, $now, $arguments);
+		$this->scheduleBackgroundJob(ScheduleJob::class, $now, $arguments);
 
 		$inThreeDays = $now + (3 * 86400);
 		$this->scheduleBackgroundJob(RepairSyncJob::class, $inThreeDays, $arguments);
