@@ -38,7 +38,6 @@ class AdminSettings implements ISettings {
 	private MicrosoftIntegration $microsoftIntegration;
 	private IConfig $config;
 	private AiIntegrationsService $aiIntegrationsService;
-	private ClassificationSettingsService $classificationSettingsService;
 
 	public function __construct(
 		IInitialStateService $initialStateService,
@@ -48,8 +47,8 @@ class AdminSettings implements ISettings {
 		MicrosoftIntegration $microsoftIntegration,
 		IConfig $config,
 		AiIntegrationsService $aiIntegrationsService,
-		ClassificationSettingsService $classificationSettingsService,
 		private Defaults $themingDefaults,
+		private ClassificationSettingsService $classificationSettingsService,
 	) {
 		$this->initialStateService = $initialStateService;
 		$this->provisioningManager = $provisioningManager;
@@ -58,7 +57,6 @@ class AdminSettings implements ISettings {
 		$this->microsoftIntegration = $microsoftIntegration;
 		$this->config = $config;
 		$this->aiIntegrationsService = $aiIntegrationsService;
-		$this->classificationSettingsService = $classificationSettingsService;
 	}
 
 	#[\Override]
@@ -118,6 +116,11 @@ class AdminSettings implements ISettings {
 			'google_oauth_redirect_url',
 			$this->googleIntegration->getRedirectUrl(),
 		);
+		$this->initialStateService->provideInitialState(
+			Application::APP_ID,
+			'importance_classification_default',
+			$this->classificationSettingsService->isClassificationEnabledByDefault(),
+		);
 		$this->initialStateService->provideInitialState(
 			Application::APP_ID,
 			'microsoft_oauth_tenant_id',
@@ -139,12 +142,6 @@ class AdminSettings implements ISettings {
 			$this->themingDefaults->buildDocLinkToKey('admin-groupware-oauth-microsoft'),
 		);
 
-		$this->initialStateService->provideInitialState(
-			Application::APP_ID,
-			'importance_classification_default',
-			$this->classificationSettingsService->isClassificationEnabledByDefault(),
-		);
-
 		return new TemplateResponse(Application::APP_ID, 'settings-admin');
 	}
 
